//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\/
//
//	File: WinMain.h
//	
//	Author: Brand Gamblin
//
//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\//\\/

#ifndef WINMAIN_H
#define WINMAIN_H

#ifndef _WINDOWS_
#include <windows.h>
#endif

#ifndef _D3D8_H_
#include <d3d8.h>
#endif

#ifndef __D3DX8MATH_H__
#include <d3dx8math.h>
#endif

#ifndef SAFE_DELETE
#define SAFE_DELETE(a) { if (a) { delete a; a=NULL; } }
#endif
#ifndef SAFE_RELEASE
#define SAFE_RELEASE(a) { if (a) { a->Release(); a=NULL; } }
#endif

#define VIEWPORT_WIDTH 640
#define VIEWPORT_HEIGHT 480

// The custom FVF, which describes the custom vertex structure.
#define D3DFVF_CUSTOMVERTEX (D3DFVF_XYZ|D3DFVF_DIFFUSE|D3DFVF_TEX1)

struct CUSTOMVERTEX
{
    D3DXVECTOR3 position; // The position.
    D3DCOLOR    color;    // The color.
    FLOAT       tu, tv;   // The texture coordinates.
};

class Texture
{
public:
	Texture() { Init(); }
	~Texture() { Destroy(); }
	void Init ();
	void Destroy() { Clear(); }
	void Clear();

	LPDIRECT3DTEXTURE8	pTexture;
	int m_Width;
	int m_Height;
	int m_Pitch;
protected:
private:
};

class Poly
{
public:
	Poly() : m_VertexBuffer(NULL) { }
	~Poly() { Destroy(); }
	void Init();
	void Destroy() { Clear(); }
	void Clear();
	void SetVertRect(int x, int y, int w, int h, float d); // Sets the rectangle used by the Verticies.
	
	LPDIRECT3DVERTEXBUFFER8	m_VertexBuffer;
	Texture					m_Tex;
protected:
private:
};

class D3DObj
{
public:
	D3DObj() : m_pD3D(NULL), m_pd3dDevice(NULL) { Init(); }
	~D3DObj() { Destroy(); }
	void Init() { Clear(); }
	void Init( HWND hWnd);
	void Destroy() { Clear(); }
	void Clear();
	int Render();
		
	LPDIRECT3D8					m_pD3D;
	LPDIRECT3DDEVICE8			m_pd3dDevice;
protected:	
private:
};








#endif
